Video analysis (video module) {#tutorial_table_of_content_video}
=============================

Look here in order to find use on your video stream algorithms like: motion extraction, feature
tracking and foreground extractions.

-   @subpage tutorial_background_subtraction

    *Languages:* C++, Java, Python

    *Compatibility:* \> OpenCV 2.4.6

    *Author:* Domenico Daniele Bloisi

    We will learn how to extract foreground masks from both videos and sequences of images and
    to show them.

-   @subpage tutorial_meanshift

    *Languages:* C++, Java, Python

    Learn how to use the Meanshift and Camshift algorithms to track objects in videos.

-   @subpage tutorial_optical_flow

    *Languages:* C++, Java, Python

    We will learn how to use optical flow methods to track sparse features or to create a dense representation.
